{% load i18n %}
{% load static %}
<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="UTF-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>Server Error</title>
    <link rel="shortcut icon" href="{% static 'postorius/img/favicon.ico' %}">
    <link rel="stylesheet" href="{% static 'postorius/libs/bootstrap/css/bootstrap.min.css' %}">
    <link rel="stylesheet" href="{% static 'django-mailman3/css/main.css' %}">
    <link rel="stylesheet" href="{% static 'postorius/css/style.css' %}">
    {% block additionalcss %}{% endblock %}
  </head>
  <body>
    <div class="container">
      <h1>{% trans 'Server error' %}</h1>
      <div class="alert alert-danger">{% trans "An error occurred while processing your request." %}</div>
    </div>
  </body>
</html>
