# -*- coding: utf-8 -*-
# Generated by Django 1.11.14 on 2018-07-12 05:36
from __future__ import unicode_literals

from django.db import migrations, models


# flake8: noqa


class Migration(migrations.Migration):

    dependencies = [
        ('postorius', '0006_auto_20180711_1359'),
    ]

    operations = [
        migrations.AlterField(
            model_name='emailtemplate',
            name='language',
            field=models.CharField(blank=True, choices=[('ar', 'Arabic'), ('ast', 'Asturian'), ('ca', 'Catalan'), ('cs', 'Czech'), ('da', 'Danish'), ('de', 'German'), ('el', 'Greek'), ('es', 'Spanish'), ('et', 'Estonian'), ('eu', 'Euskara'), ('fi', 'Finnish'), ('fr', 'French'), ('gl', 'Galician'), ('he', 'Hebrew'), ('hr', 'Croatian'), ('hu', 'Hungarian'), ('ia', 'Interlingua'), ('it', 'Italian'), ('ja', 'Japanese'), ('ko', 'Korean'), ('lt', 'Lithuanian'), ('nl', 'Dutch'), ('no', 'Norwegian'), ('pl', 'Polish'), ('pt', 'Protuguese'), ('pt_BR', 'Protuguese (Brazil)'), ('ro', 'Romanian'), ('ru', 'Russian'), ('sk', 'Slovak'), ('sl', 'Slovenian'), ('sr', 'Serbian'), ('sv', 'Swedish'), ('tr', 'Turkish'), ('uk', 'Ukrainian'), ('vi', 'Vietnamese'), ('zh_CN', 'Chinese'), ('zh_TW', 'Chinese (Taiwan)'), ('en', 'English (USA)')], help_text="Language for the template, this should be the list's preferred language.", max_length=5),
        ),
    ]
