{% extends "postorius/base.html" %}
{% load i18n %}
{% load bootstrap_tags %}
{% load nav_helpers %}

{% block head_title %}
{% trans 'Templates' %}
{% endblock head_title %}

{% block content  %}
    {% list_nav 'templates' 'msgid:title:list_templates' %}

<h3>{% blocktrans with name=object.name %}Template '{{ name }}'{% endblocktrans %}<br />
    <small>{{ object.description }}</small>
</h3>

<form action="" method="post" class="form-group">
  {% csrf_token %}
  {% bootstrap_form_horizontal form 3 8 'Update' %}
  <p hidden>{% trans 'Update' %}</p>
</form>

{% endblock content %}
