# Generated by Django 2.2.11 on 2021-03-30 05:48

from django.db import migrations, models


# flake8: noqa

class Migration(migrations.Migration):

    dependencies = [
        ('postorius', '0013_auto_20201116_0058'),
    ]

    operations = [
        migrations.AlterField(
            model_name='emailtemplate',
            name='name',
            field=models.CharField(choices=[('list:admin:action:post', '[list:admin:action:post] - Sent to the list administrators when moderator approval for a posting is required.'), ('list:admin:action:subscribe', '[list:admin:action:subscribe] - Sent to the list administrators when moderator approval for a subscription request is required.'), ('list:admin:action:unsubscribe', '[list:admin:action:unsubscribe] - Sent to the list administrators when moderator approval for an unsubscription request is required.'), ('list:admin:notice:subscribe', '[list:admin:notice:subscribe] - Sent to the list administrators to notify them when a new member has been subscribed.'), ('list:admin:notice:unrecognized', '[list:admin:notice:unrecognized] - Sent to the list administrators when a bounce message in an unrecognized format has been received.'), ('list:admin:notice:increment', "[list:admin:notice:increment] - Sent to the list administrators to notify them when a member's bounce score is incremented."), ('list:admin:notice:disable', "[list:admin:notice:disable] - Sent to the list administrators to notify them when a member's delivery is disabled due to excessive bounces."), ('list:admin:notice:unsubscribe', '[list:admin:notice:unsubscribe] - Sent to the list administrators to notify them when a member has been unsubscribed.'), ('list:member:digest:footer', '[list:member:digest:footer] - The footer for a digest message.'), ('list:member:digest:header', '[list:member:digest:header] - The header for a digest message.'), ('list:member:digest:masthead', '[list:member:digest:masthead] - The digest “masthead”; i.e. a common introduction for all digest messages.'), ('list:member:regular:footer', '[list:member:regular:footer] - The footer for a regular (non-digest) message.'), ('list:member:regular:header', '[list:member:regular:header] - The header for a regular (non-digest) message.'), ('list:user:action:subscribe', '[list:user:action:subscribe] - The message sent to subscribers when a subscription confirmation is required.'), ('list:user:action:unsubscribe', '[list:user:action:unsubscribe] - The message sent to subscribers when an unsubscription confirmation is required.'), ('list:user:action:invite', '[list:user:action:invite] - The message sent to subscribers when they are invited to join a list.'), ('list:user:notice:goodbye', '[list:user:notice:goodbye] - The notice sent to a member when they unsubscribe from a mailing list.'), ('list:user:notice:hold', '[list:user:notice:hold] - The notice sent to a poster when their message is being held for moderator approval.'), ('list:user:notice:no-more-today', '[list:user:notice:no-more-today] - Sent to a user when the maximum number of autoresponses has been reached for that day.'), ('list:user:notice:post', '[list:user:notice:post] - Notice sent to a poster when their message has been received by the mailing list.'), ('list:user:notice:probe', '[list:user:notice:probe] - A bounce probe sent to a member when their subscription has been disabled due to bounces.'), ('list:user:notice:refuse', '[list:user:notice:refuse] - Notice sent to a poster when their message has been rejected by the list’s moderator.'), ('list:user:notice:rejected', '[list:user:notice:rejected] - Notice sent to a poster when their message has been rejected automatically.'), ('list:user:notice:welcome', '[list:user:notice:welcome] - The notice sent to a member when they are subscribed to the mailing list.'), ('list:user:notice:warning', '[list:user:notice:warning] - The notice sent to a member when their membership has been disabled due to excessive bounces.')], help_text='Choose the template you want to customize.', max_length=100),
        ),
    ]
